@@ -27,10 +27,10 @@ extern "C" {
 #endif /* __cplusplus */
 
 #include "gconf-error.h"
-#include "GConf.h"
+#include "GConfX.h"
 #include "gconf-database.h"
 
-PortableServer_POA gconf_get_poa ();
+PortableServer_POA gconf_get_poa (void);
 
 /* return TRUE if the exception was set, clear err if needed */
 gboolean gconf_set_exception (GError** err, CORBA_Environment* ev);
@@ -44,6 +44,12 @@ gboolean gconfd_logfile_change_listener (GConfDatabase *db,
 
 gboolean gconfd_check_in_shutdown (CORBA_Environment *ev);
 
+void gconfd_notify_other_listeners (GConfDatabase *modified_db,
+				    GConfSources  *modified_sources,
+                                    const char    *key);
+
+void gconfd_need_log_cleanup (void);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
